@@ -1,5 +1,12 @@
 var NAVTREEINDEX7 =
 {
+"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,0,26,4],
+"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa":[10,0,26,1],
+"structpw__control__events.html#ad23091c8931adf9aa85564b31e2d9ca8":[10,0,26,0],
+"structpw__control__events.html#adbd47ebc650888ca6235b763fa3f6ef2":[10,0,26,2],
+"structpw__core__events.html":[10,0,27],
+"structpw__core__events.html#a55c28400675736b9365e711884f7a73b":[10,0,27,3],
+"structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063":[10,0,27,7],
 "structpw__core__events.html#a6cf547297486e97c8969a1e08d837955":[10,0,27,2],
 "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,0,27,8],
 "structpw__core__events.html#a9a930f32ad895727dffbeb6ae4c6e04d":[10,0,27,6],
@@ -242,12 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__node__info.html#aa2bd90f2d1c5f570eac18709b2acc387":[10,0,79,8],
 "structpw__node__info.html#ab5c2457030a463ccdc6ca5291ced856f":[10,0,79,6],
 "structpw__node__info.html#abc111c6b06e8564fd4a03854e109563b":[10,0,79,9],
-"structpw__node__info.html#ac312e1844784e77e412f6bb341814372":[10,0,79,4],
-"structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1":[10,0,79,7],
-"structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75":[10,0,79,5],
-"structpw__node__methods.html":[10,0,80],
-"structpw__node__methods.html#a01dbc165d13370efdb6a54a5c3f40f41":[10,0,80,0],
-"structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a":[10,0,80,3],
-"structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266":[10,0,80,1],
-"structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569":[10,0,80,5]
+"structpw__node__info.html#ac312e1844784e77e412f6bb341814372":[10,0,79,4]
 };
